# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: asr.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'asr.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tasr.proto\x12\x03\x61sr\"<\n\x14\x43reateSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\"9\n\x15\x43reateSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"=\n\x11TranscribeRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61udio_chunks\x18\x02 \x03(\x0c\"J\n\x12TranscribeResponse\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\x12\n\nsession_id\x18\x03 \x01(\t\"+\n\x15\x44\x65stroySessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x07\n\x05\x45mpty\"`\n\rStatsResponse\x12\x17\n\x0f\x61\x63tive_sessions\x18\x01 \x01(\x05\x12\x16\n\x0etotal_requests\x18\x02 \x01(\x03\x12\x1e\n\x16total_chunks_processed\x18\x03 \x01(\x03\x32\xf9\x01\n\nASRService\x12\x46\n\rCreateSession\x12\x19.asr.CreateSessionRequest\x1a\x1a.asr.CreateSessionResponse\x12=\n\nTranscribe\x12\x16.asr.TranscribeRequest\x1a\x17.asr.TranscribeResponse\x12\x38\n\x0e\x44\x65stroySession\x12\x1a.asr.DestroySessionRequest\x1a\n.asr.Empty\x12*\n\x08GetStats\x12\n.asr.Empty\x1a\x12.asr.StatsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREATESESSIONREQUEST']._serialized_start=18
  _globals['_CREATESESSIONREQUEST']._serialized_end=78
  _globals['_CREATESESSIONRESPONSE']._serialized_start=80
  _globals['_CREATESESSIONRESPONSE']._serialized_end=137
  _globals['_TRANSCRIBEREQUEST']._serialized_start=139
  _globals['_TRANSCRIBEREQUEST']._serialized_end=200
  _globals['_TRANSCRIBERESPONSE']._serialized_start=202
  _globals['_TRANSCRIBERESPONSE']._serialized_end=276
  _globals['_DESTROYSESSIONREQUEST']._serialized_start=278
  _globals['_DESTROYSESSIONREQUEST']._serialized_end=321
  _globals['_EMPTY']._serialized_start=323
  _globals['_EMPTY']._serialized_end=330
  _globals['_STATSRESPONSE']._serialized_start=332
  _globals['_STATSRESPONSE']._serialized_end=428
  _globals['_ASRSERVICE']._serialized_start=431
  _globals['_ASRSERVICE']._serialized_end=680
# @@protoc_insertion_point(module_scope)
