"""
Vision describer base class

Re-exported from vixio.providers.vision for backward compatibility.
The canonical definition is in providers.vision.VisionDescriber.
"""

# Re-export from canonical location
from vixio.providers.vision import VisionDescriber

__all__ = ["VisionDescriber"]
