# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: vad.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'vad.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tvad.proto\x12\x03vad\"t\n\x14\x43reateSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tthreshold\x18\x02 \x01(\x02\x12\x15\n\rthreshold_low\x18\x03 \x01(\x02\x12\x1e\n\x16\x66rame_window_threshold\x18\x04 \x01(\x05\"9\n\x15\x43reateSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"F\n\rDetectRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\naudio_data\x18\x02 \x01(\x0c\x12\r\n\x05\x65vent\x18\x03 \x01(\t\"L\n\x0e\x44\x65tectResponse\x12\x11\n\thas_voice\x18\x01 \x01(\x08\x12\x13\n\x0bis_speaking\x18\x02 \x01(\x08\x12\x12\n\nsession_id\x18\x03 \x01(\t\")\n\x13ResetSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"+\n\x15\x44\x65stroySessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x07\n\x05\x45mpty\"e\n\rStatsResponse\x12\x17\n\x0f\x61\x63tive_sessions\x18\x01 \x01(\x05\x12\x16\n\x0etotal_requests\x18\x02 \x01(\x03\x12#\n\x08sessions\x18\x03 \x03(\x0b\x32\x11.vad.SessionStats\"b\n\x0cSessionStats\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x15\n\rrequest_count\x18\x02 \x01(\x03\x12\x13\n\x0b\x61ge_seconds\x18\x03 \x01(\x01\x12\x12\n\nvad_locked\x18\x04 \x01(\x08\x32\xa3\x02\n\nVADService\x12\x46\n\rCreateSession\x12\x19.vad.CreateSessionRequest\x1a\x1a.vad.CreateSessionResponse\x12\x31\n\x06\x44\x65tect\x12\x12.vad.DetectRequest\x1a\x13.vad.DetectResponse\x12\x34\n\x0cResetSession\x12\x18.vad.ResetSessionRequest\x1a\n.vad.Empty\x12\x38\n\x0e\x44\x65stroySession\x12\x1a.vad.DestroySessionRequest\x1a\n.vad.Empty\x12*\n\x08GetStats\x12\n.vad.Empty\x1a\x12.vad.StatsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vad_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREATESESSIONREQUEST']._serialized_start=18
  _globals['_CREATESESSIONREQUEST']._serialized_end=134
  _globals['_CREATESESSIONRESPONSE']._serialized_start=136
  _globals['_CREATESESSIONRESPONSE']._serialized_end=193
  _globals['_DETECTREQUEST']._serialized_start=195
  _globals['_DETECTREQUEST']._serialized_end=265
  _globals['_DETECTRESPONSE']._serialized_start=267
  _globals['_DETECTRESPONSE']._serialized_end=343
  _globals['_RESETSESSIONREQUEST']._serialized_start=345
  _globals['_RESETSESSIONREQUEST']._serialized_end=386
  _globals['_DESTROYSESSIONREQUEST']._serialized_start=388
  _globals['_DESTROYSESSIONREQUEST']._serialized_end=431
  _globals['_EMPTY']._serialized_start=433
  _globals['_EMPTY']._serialized_end=440
  _globals['_STATSRESPONSE']._serialized_start=442
  _globals['_STATSRESPONSE']._serialized_end=543
  _globals['_SESSIONSTATS']._serialized_start=545
  _globals['_SESSIONSTATS']._serialized_end=643
  _globals['_VADSERVICE']._serialized_start=646
  _globals['_VADSERVICE']._serialized_end=937
# @@protoc_insertion_point(module_scope)
